==> haskell-hslua-module-system-1.1.2-47.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-module-system.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-module-system
version:              1.1.2
visibility:           public
id:                   hslua-module-system-1.1.2-AfZ90C6WY3qAjj0an2An5w
key:                  hslua-module-system-1.1.2-AfZ90C6WY3qAjj0an2An5w
license:              MIT
copyright:            © 2019-2024 Albert Krewinkel <tarleb@hslua.org>
maintainer:           tarleb@hslua.org
author:               Albert Krewinkel
homepage:             https://github.com/hslua/hslua
synopsis:             Lua module wrapper around Haskell'\''s System module.
description:
    Provides access to system information and
    functionality to Lua scripts via Haskell'\''s `System`
    module.

    This package is part of HsLua, a Haskell framework
    built around the embeddable scripting language
    <https://lua.org Lua>.

category:             Foreign
abi:                  d0a9b67dec293f92468ba2e488e7e198
exposed:              True
exposed-modules:      HsLua.Module.System
hidden-modules:       HsLua.Module.SystemUtils
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hslua-module-system-1.1.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hslua-module-system-1.1.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hslua-module-system-1.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-module-system
hs-libraries:         HShslua-module-system-1.1.2-AfZ90C6WY3qAjj0an2An5w
depends:
    base-4.18.2.1 directory-1.3.8.5 exceptions-0.10.7
    hslua-core-2.3.2-LsuRv5joEv2BEnjW1fCbrM
    hslua-marshalling-2.3.1-2wvb5zI3Ais62iyLUWMiUH
    hslua-packaging-2.3.1-CX7lhwYsgw0Jci7JtzHprm
    temporary-1.3-DmygwHaZA8GJCfyTYb6Tkl text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hslua-module-system/html/hslua-module-system.haddock

haddock-html:         /usr/share/doc/haskell-hslua-module-system/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-module-system-1.1.2-48-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-module-system.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-module-system
version:              1.1.2
visibility:           public
id:                   hslua-module-system-1.1.2-Gz3xDihO0rAIrNFdtD64si
key:                  hslua-module-system-1.1.2-Gz3xDihO0rAIrNFdtD64si
license:              MIT
copyright:            © 2019-2024 Albert Krewinkel <tarleb@hslua.org>
maintainer:           tarleb@hslua.org
author:               Albert Krewinkel
homepage:             https://github.com/hslua/hslua
synopsis:             Lua module wrapper around Haskell'\''s System module.
description:
    Provides access to system information and
    functionality to Lua scripts via Haskell'\''s `System`
    module.

    This package is part of HsLua, a Haskell framework
    built around the embeddable scripting language
    <https://lua.org Lua>.

category:             Foreign
abi:                  f90278fad7483b52886841e8c48094b2
exposed:              True
exposed-modules:      HsLua.Module.System
hidden-modules:       HsLua.Module.SystemUtils
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hslua-module-system-1.1.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hslua-module-system-1.1.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hslua-module-system-1.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-module-system
hs-libraries:         HShslua-module-system-1.1.2-Gz3xDihO0rAIrNFdtD64si
depends:
    base-4.18.2.1 directory-1.3.8.5 exceptions-0.10.7
    hslua-core-2.3.2-6IHXwFbRgmjH5Bn36TUerg
    hslua-marshalling-2.3.1-Lphd68rczTTD9xcjuNYtYD
    hslua-packaging-2.3.1-4anfJzyA7OLGShitXl91KS
    temporary-1.3-29RL4tTXoFB72QSCtJnhBC text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hslua-module-system/html/hslua-module-system.haddock

haddock-html:         /usr/share/doc/haskell-hslua-module-system/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
